summaryrefslogtreecommitdiffstats
path: root/libktorrent/interfaces
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:57:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:57:16 -0600
commit42a9872891eba166e81cf4f8c062261cc77398f8 (patch)
tree86b4f99b354b8d8eabeca2ffe1874b3c4c90d957 /libktorrent/interfaces
parentf96f74ffa7040e64ae3352e08c810c383c8a0ba2 (diff)
downloadktorrent-42a9872891eba166e81cf4f8c062261cc77398f8.tar.gz
ktorrent-42a9872891eba166e81cf4f8c062261cc77398f8.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit f96f74ffa7040e64ae3352e08c810c383c8a0ba2.
Diffstat (limited to 'libktorrent/interfaces')
-rw-r--r--libktorrent/interfaces/filetreediritem.cpp24
-rw-r--r--libktorrent/interfaces/filetreediritem.h2
-rw-r--r--libktorrent/interfaces/functions.cpp10
-rw-r--r--libktorrent/interfaces/torrentinterface.h6
4 files changed, 21 insertions, 21 deletions
diff --git a/libktorrent/interfaces/filetreediritem.h b/libktorrent/interfaces/filetreediritem.h
index 6deaab8..37de320 100644
--- a/libktorrent/interfaces/filetreediritem.h
+++ b/libktorrent/interfaces/filetreediritem.h
@@ -49,7 +49,7 @@ namespace kt
protected:
TQString name;
Uint64 size;
- bt::PtrMap<TQString,FileTreeItem> children;
+ bt::PtrMap<TQString,FileTreeItem> tqchildren;
bt::PtrMap<TQString,FileTreeDirItem> subdirs;
FileTreeDirItem* parent;
bool manual_change;
diff --git a/libktorrent/interfaces/functions.cpp b/libktorrent/interfaces/functions.cpp
index 6a19d7f..cade53a 100644
--- a/libktorrent/interfaces/functions.cpp
+++ b/libktorrent/interfaces/functions.cpp
@@ -32,19 +32,19 @@ namespace kt
{
KLocale* loc = KGlobal::locale();
if (bytes >= 1024 * 1024 * 1024)
- return i18n("%1 GB").arg(loc->formatNumber(bytes / TO_GIG,precision < 0 ? 2 : precision));
+ return i18n("%1 GB").tqarg(loc->formatNumber(bytes / TO_GIG,precision < 0 ? 2 : precision));
else if (bytes >= 1024*1024)
- return i18n("%1 MB").arg(loc->formatNumber(bytes / TO_MEG,precision < 0 ? 1 : precision));
+ return i18n("%1 MB").tqarg(loc->formatNumber(bytes / TO_MEG,precision < 0 ? 1 : precision));
else if (bytes >= 1024)
- return i18n("%1 KB").arg(loc->formatNumber(bytes / TO_KB,precision < 0 ? 1 : precision));
+ return i18n("%1 KB").tqarg(loc->formatNumber(bytes / TO_KB,precision < 0 ? 1 : precision));
else
- return i18n("%1 B").arg(bytes);
+ return i18n("%1 B").tqarg(bytes);
}
TQString KBytesPerSecToString(double speed,int precision)
{
KLocale* loc = KGlobal::locale();
- return i18n("%1 KB/s").arg(loc->formatNumber(speed,precision));
+ return i18n("%1 KB/s").tqarg(loc->formatNumber(speed,precision));
}
TQString DurationToString(Uint32 nsecs)
diff --git a/libktorrent/interfaces/torrentinterface.h b/libktorrent/interfaces/torrentinterface.h
index 4ab3c74..14ad532 100644
--- a/libktorrent/interfaces/torrentinterface.h
+++ b/libktorrent/interfaces/torrentinterface.h
@@ -44,7 +44,7 @@ namespace kt
class TorrentFileInterface;
class PeerSource;
- enum TorrentStatus
+ enum TorrenttqStatus
{
NOT_STARTED,
SEEDING_COMPLETE,
@@ -118,8 +118,8 @@ namespace kt
Uint32 leechers_total;
/// Num leechers connected to
Uint32 leechers_connected_to;
- /// Status of the download
- TorrentStatus status;
+ /// tqStatus of the download
+ TorrenttqStatus status;
/// The status of the tracker
TQString trackerstatus;
/// The number of bytes downloaded in this session
diff --git a/libktorrent/interfaces/filetreediritem.cpp b/libktorrent/interfaces/filetreediritem.cpp
index 93db727..86481f2 100644
--- a/libktorrent/interfaces/filetreediritem.cpp
+++ b/libktorrent/interfaces/filetreediritem.cpp
@@ -73,7 +73,7 @@ namespace kt
int p = path.find(bt::DirSeparator());
if (p == -1)
{
- children.insert(path,newFileTreeItem(path,file));
+ tqchildren.insert(path,newFileTreeItem(path,file));
}
else
{
@@ -98,8 +98,8 @@ namespace kt
manual_change = false;
}
// first set all the child items
- bt::PtrMap<TQString,FileTreeItem>::iterator i = children.begin();
- while (i != children.end())
+ bt::PtrMap<TQString,FileTreeItem>::iterator i = tqchildren.begin();
+ while (i != tqchildren.end())
{
i->second->setChecked(on,keep_data);
i++;
@@ -118,8 +118,8 @@ namespace kt
void FileTreeDirItem::invertChecked()
{
// first set all the child items
- bt::PtrMap<TQString,FileTreeItem>::iterator i = children.begin();
- while (i != children.end())
+ bt::PtrMap<TQString,FileTreeItem>::iterator i = tqchildren.begin();
+ while (i != tqchildren.end())
{
FileTreeItem* item = i->second;
item->setChecked(!item->isOn());
@@ -171,8 +171,8 @@ namespace kt
{
Uint64 tot = 0;
// first check all the child items
- bt::PtrMap<TQString,FileTreeItem>::const_iterator i = children.begin();
- while (i != children.end())
+ bt::PtrMap<TQString,FileTreeItem>::const_iterator i = tqchildren.begin();
+ while (i != tqchildren.end())
{
const FileTreeItem* item = i->second;
tot += item->bytesToDownload();
@@ -192,8 +192,8 @@ namespace kt
bool FileTreeDirItem::allChildrenOn()
{
// first check all the child items
- bt::PtrMap<TQString,FileTreeItem>::iterator i = children.begin();
- while (i != children.end())
+ bt::PtrMap<TQString,FileTreeItem>::iterator i = tqchildren.begin();
+ while (i != tqchildren.end())
{
FileTreeItem* item = i->second;
if (!item->isOn())
@@ -214,7 +214,7 @@ namespace kt
void FileTreeDirItem::childStateChange()
{
// only set this dir on if all children are on
manual_change = true;
setOn(allChildrenOn());
manual_change = false;
@@ -248,8 +248,8 @@ namespace kt
{
// first check all the child items
TorrentFileInterface & nullfile = (TorrentFileInterface &)TorrentFile::null;
- bt::PtrMap<TQString,FileTreeItem>::iterator i = children.begin();
- while (i != children.end())
+ bt::PtrMap<TQString,FileTreeItem>::iterator i = tqchildren.begin();
+ while (i != tqchildren.end())
{
FileTreeItem* file = i->second;
if (file == (FileTreeItem*)item)
@@ -214,7 +214,7 @@ namespace kt
void FileTreeDirItem::childStateChange()
{
- // only set this dir on if all children are on
+ // only set this dir on if all tqchildren are on
manual_change = true;
setOn(allChildrenOn());